#!/usr/bin/php
<?php

/*******************************************************************************
* Header
********************************************************************************

TICKET: 10109705
AUTOR: Guilherme Fontans
CRIADO EM: 13/05/2016 14:20:00

REVISÕES:
--------------------------------------------------------------

********************************************************************************/

include_once '/usr/local/opmon/libexec/php-nagios-plugins/Nagios_Plugin.php';
ini_set('error_reporting', 'E_ALL & ~ E_NOTICE & ~ E_DEPRECATED');
define(VERSION, '1.0');
define(WARNING_VALUE_DEFAULT, '100:');
define(CRITICAL_VALUE_DEFAULT, '50:');

function set_nagios()
{

    global $np;
    $np = new Nagios_Plugin(
        array(
            'version' => VERSION. "[www.opservices.com.br/suporte]",
            'blurb' => "Developed by:\n\tOpServices\n",
            'Author' => "Guilherme Fontans - guilherme.opservices@opservices.com.br",
            'usage' => "Usage:\n\t%s -a <account> -u <username> -p <password> -w[warning] -c [critical]",)
    );
    $np->add_arg("account|a=s", "Account for connection", true);
    $np->add_arg("username|u=s", "User for connection", true);
    $np->add_arg("password|p=s", "Password for connection", true);
    $np->add_arg("warning|w=i", "Warning value[default=100:]");
    $np->add_arg("critical|c=i", "Critical value[default=50:]");
    $np->add_arg("perfdata", "Show perfdata");
    $np->add_arg("man", "Show guideline");

    $np->getopts();

    if (isset($np->opts['warning']) and isset($np->opts['critical'])) {
        $np->set_thresholds($np->opts['warning'], $np->opts['critical'], 0);
    } else {
        $np->set_thresholds(WARNING_VALUE_DEFAULT, CRITICAL_VALUE_DEFAULT, 0);
    }
}

/*******************************************************************************
* Exibi o manual do software
********************************************************************************/

function getGuideLine()
{

    print <<<EOF

-------------------------------------------------------------------------------
Manual de exemplo.
-------------------------------------------------------------------------------

Descrição do plugin:
    Este plugin monitora o crédito disponível na conta do zenvia.

Dependências:
    php
    php-xml

Funcionamento:
    O plugin recebe a conta, usuário e senha, acessa o site da zenvia e pega o
    crédito exibido na tela inicial

Exemplos de execução e retorno do comando:
    ./check_credito_zenvia.php -a 'conta' -u 'user@user.com' -p 'pass' -w 200: -c 300:

EOF;

    exit(OK);

}

function getCredit()
{

    global $np;

    $url = "https://connect.zenvia360.com/manager/login.do";
    $userAgent  = "Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.1; Trident/5.0;)";
    $userAgent .= "SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729;";
    $userAgent .= ".NET CLR 3.0.30729; Media Center PC 6.0; InfoPath.3)";
    $headers = array('Content-Type' => 'application/x-www-form-urlencoded');
    $post = array(
        'account' => $np->account,
        'username' => $np->username,
        'password' => $np->password
    );

    $ch = curl_init();

    $curl_options =
        array(
            CURLOPT_URL => $url,
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_POST => true,
            CURLOPT_FOLLOWLOCATION => true,
            CURLOPT_HTTPHEADER => $headers,
            CURLOPT_USERAGENT => $userAgent,
            CURLOPT_POSTFIELDS => $post
        );

    curl_setopt_array($ch, $curl_options);
    $result = curl_exec($ch);
    curl_close($ch);
    $dom = new DOMDocument;
    $dom->loadHTML($result);
    $html_filtered = $dom->getElementsByTagName('b');
    $r = $html_filtered->item(1)->nodeValue;
    $pattern = "/Sua conta poss.i (\d+).+cr/";
    preg_match($pattern, $r, $matches);

    if ($matches[1] == null) {
        throw new Exception("Não foi possível localizar o crédito disponível");
    } else {
        return $matches[1];
    }
}

function main()
{
    global $np;
    set_nagios();

    if (isset($np->opts['man'])) {
        getGuideLine();
    }

    try {
        $credit = getCredit();
        $np->add_perfdata("credito", $credit, "", $np->threshold());

        $np->nagios_exit(
            $np->check_threshold($credit),
            "Crédito disponível: $credit"
        );
    } catch (Exception $ex) {
        $np->nagios_exit(3, $ex->getMessage());
    }
}

main();
